# opep

Open PEPs on your terminal.

## Installation

You can simply use `pip` to install `opep`:

```
$ pip install opep
```

## Usage

> You’d be surprised how many numbers are out there! — [Hynek Schlawack](https://twitter.com/hynek/status/704236819651624960) (out of context)

```
$ opep 8
```

![image](https://raw.githubusercontent.com/vinayak-mehta/opep/master/opep.png)

You can also stumble upon a PEP using:

```
$ opep random
```

## Versioning

`opep` uses [Semantic Versioning](https://semver.org/). For the available versions, see the tags on the GitHub repository.

## License

This project is licensed under the Apache License, see the [LICENSE](https://github.com/vinayak-mehta/opep/blob/master/LICENSE) file for details.
